Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(18)

Unified Diff: media/video/video_decode_accelerator.cc

Issue 1839193003: Reland: Introduce GpuVideoDecodeAcceleratorFactory. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Created 4 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: media/video/video_decode_accelerator.cc
diff --git a/media/video/video_decode_accelerator.cc b/media/video/video_decode_accelerator.cc
index f99787a6fd0dc532aa48a907f32d8d196dfb0c2a..00ae88c1d1ca059e082f3be9744dae7aea84e98b 100644
--- a/media/video/video_decode_accelerator.cc
+++ b/media/video/video_decode_accelerator.cc
@@ -34,9 +34,11 @@ void VideoDecodeAccelerator::SetCdm(int cdm_id) {
NOTREACHED() << "By default CDM is not supported.";
}
-bool VideoDecodeAccelerator::CanDecodeOnIOThread() {
- // GPU process subclasses must override this.
- LOG(FATAL) << "This should only get called in the GPU process";
+bool VideoDecodeAccelerator::TryToSetupDecodeOnSeparateThread(
+ const base::WeakPtr<Client>& decode_client,
+ const scoped_refptr<base::SingleThreadTaskRunner>& decode_task_runner) {
+ // Implementations in the process that VDA runs in must override this.
+ LOG(FATAL) << "This may only be called in the same process as VDA impl.";
return false; // not reached
}

Powered by Google App Engine
This is Rietveld 408576698